@@ -30,7 +30,7 @@
  * 
  * You should have received a copy of the GNU General Public License along with
  * GNU Smalltalk; see the file COPYING.  If not, write to the Free Software
- * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
+ * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  
  *
  ***********************************************************************/
 
@@ -323,8 +323,6 @@ _gst_msg_sendf (PTR resultPtr,
 	  break;
 
 	case 'C':
-	  /* !!! Fix this -- it is ugly, but OS/2 compilers don't like
-	     it without */
 	  *(PTR *) resultPtr =
 	    IS_NIL (result) ? NULL : COBJECT_VALUE (result);
 	  break;
