@@ -339,12 +339,9 @@ my_stat (const char *name,
       errno = 0;
       out->st_mode = statOut.st_mode;
       out->st_size = statOut.st_size;
-      out->st_aTime =
-	_gst_adjust_time_zone (statOut.st_atime) - 86400 * 10959;
-      out->st_mTime =
-	_gst_adjust_time_zone (statOut.st_mtime) - 86400 * 10959;
-      out->st_cTime =
-	_gst_adjust_time_zone (statOut.st_ctime) - 86400 * 10959;
+      out->st_aTime = _gst_adjust_time_zone (statOut.st_atime) - 86400 * 10957;
+      out->st_mTime = _gst_adjust_time_zone (statOut.st_mtime) - 86400 * 10957;
+      out->st_cTime = _gst_adjust_time_zone (statOut.st_ctime) - 86400 * 10957;
     }
   return (result);
 }
@@ -902,10 +899,11 @@ push_obj (cparam_union * up,
   alignInts = alignments[typ] / sizeof (long);
 
   /* Align the stack properly */
-  if ((c_arg - c_arg_vec) % alignInts)
+  if (alignInts > 0 && (c_arg - c_arg_vec) % alignInts)
     c_arg += alignInts - ((c_arg - c_arg_vec) % alignInts);
 
-  for (i = 0; i < type_sizes[typ] / sizeof (long); i++)
+  i = 0;
+  do
     {
       if (c_arg - c_arg_vec >= ARG_VEC_SIZE)
 	{
@@ -916,6 +914,7 @@ push_obj (cparam_union * up,
 	}
       *c_arg++ = up->valueVec[i];
     }
+  while (++i < type_sizes[typ] / sizeof (long));
 }
 
 OOP
